Attribute VB_Name = "UnityVersion"
Option Explicit

'Sean's snappy version checking module. This module requires the RegistryAPI module to work properly.  It checks the registry and
'sets the value of the version accordingly.  The version string for Unity 3.1(3.22) will break down like this:
'Major=3
'Minor=1
'Rev=3
'Build=22
'Version="3.1(2.3)"

'This is the type definition that holds the version
Public Type tUnityVersion
    nMajor As Integer
    nMinor As Integer
    nRev As Integer
    nBuild As Integer
    sVersion As String
End Type

'Create a globally available variable that holds an instance of the above structure that we can check in code
'elsewhere in the project
Global UnityVer As tUnityVersion

'The application needs to call this function at startup to go fetch the version information from the registry
'and store it in the global UnityVer variable defined above.
Public Function getVersion() As tUnityVersion
Dim strHoldString As String
Dim lVersionNumber As Long
Dim lBuildNumber As Long
Dim sVN As String
Dim sBN As String
    
    'The version information is stored in the root of the Active Voice registry branch as a hex string - we need
    'to pull it out and convert it to decimal such that it's readable to humans easily.
    On Error GoTo getVersion_Error

    strHoldString = "Software\Active Voice\"
    lVersionNumber = GetRegistryValue(HKEY_LOCAL_MACHINE, strHoldString, "Version Number", REG_DWORD)
    lBuildNumber = GetRegistryValue(HKEY_LOCAL_MACHINE, strHoldString, "Build Number", REG_DWORD)
    sVN = Hex$(lVersionNumber)
    sVN = String$(8 - Len(sVN), "0") & sVN
    getVersion.nMajor = Val(Left$(sVN, 4))
    getVersion.nMinor = Val(Right$(sVN, 4))
    sBN = Hex$(lBuildNumber)
    sBN = String(8 - Len(sBN), "0") & sBN
    getVersion.nRev = Val(Left$(sBN, 4))
    getVersion.nBuild = Val("&H" & Right(sBN, 4))
    getVersion.sVersion = Trim(Str(getVersion.nMajor)) & "." & Trim(Str(getVersion.nMinor)) & "(" & Trim(Str(getVersion.nRev) & "." & Trim(Str(getVersion.nBuild)) & ")")

    Exit Function
getVersion_Error:
    MsgBox "(error):" & Err.Number & " (" & Err.Description & ") in procedure getVersion of Module UnityVersion"
    Debug.Assert False
    Resume Next
End Function

'This function returns true if the local version is greater than or equal to the version passed in.
'This assumes the application has already called the GetVersion functon above and stored it in the global
'UnityVer variable defined above.  If everyone cooporates no one will get hurt.
Public Function bIsVersionGreaterThanOrEqualTo(nMajor As Integer, nMinor As Integer, nRev As Integer, nBuild As Integer) As Boolean
    If UnityVer.nMajor > nMajor Or _
       UnityVer.nMajor = nMajor And UnityVer.nMinor > nMinor Or _
       UnityVer.nMajor = nMajor And UnityVer.nMinor = nMinor And UnityVer.nRev > nRev Or _
       UnityVer.nMajor = nMajor And UnityVer.nMinor = nMinor And UnityVer.nRev = nRev And UnityVer.nBuild >= nBuild Then
        bIsVersionGreaterThanOrEqualTo = True
    Else
        bIsVersionGreaterThanOrEqualTo = False
    End If
End Function
